@@ -126,8 +126,11 @@ class SleepingCooldownMixin:
         await super().after(idle=idle)
         if self.cooldown_on & (SleepingCooldown.IDLE if idle else SleepingCooldown.BUSY):
             self.state = WorkerState.COOLDOWN
-            sleep_seconds = randint(self.cooldown_min_seconds, self.cooldown_max_seconds)  # noqa: S311
-            logger.info("%s.after() having a cooldown of %s seconds.", self, sleep_seconds)
+            if self.cooldown_min_seconds == self.cooldown_max_seconds:
+                sleep_seconds = self.cooldown_min_seconds
+            else:
+                sleep_seconds = randint(self.cooldown_min_seconds, self.cooldown_max_seconds)  # noqa: S311
+                logger.info("%s.after() having a cooldown of %s seconds.", self, sleep_seconds)
             await asyncio.sleep(sleep_seconds)
 
 
@@ -155,19 +158,16 @@ class AbstractProducer(AbstractWorker):
         logger.info("%s.run() started.", self)
         while True:
             await self.before()
-            idle = False
             try:
                 self.state = WorkerState.WORKING
                 task = await self.fetch_task()
             except InternalServiceError as exc:
                 logger.error("%s.run() failed %r", self, exc)
                 task = None
-                idle = True
             except Exception as exc:
                 logger.exception("%s.run() failed %r", self, exc)
                 task = None
-                idle = True
-            await self.after(idle=idle)
+            await self.after(idle=not task)
             if task:
                 # noinspection PyArgumentList
                 await self.engine.push(job := self.job_class(**task.job_kwargs))
